@@ -1,4 +1,4 @@
-'V1.12.01-Tqdm.desc.jitter'
+'V1.12.01-Tqdm.desc.jitter.timer'
 __all__ = ['B','Blank','BB','bbfy','C','choose','crop_from_bb','cv2', 'dumpdill','df2bbs','diff',
 'flatten','fname','fname2','glob','Glob','inspect','jitter', 'L',
 'line','loaddill','logger','extn', 'makedir', 'np', 'now','nunique','os','pd','parent','Path','pdb',
@@ -36,9 +36,9 @@ class Timer:
         self.start = time.time()
         self.N = N
 
-    def __call__(self, ix):
+    def __call__(self, ix, info=None):
         elapsed = time.time() - self.start
-        print('\r{}/{} ({:.2f}s - {:.2f}s remaining)'.format(ix+1, self.N, elapsed, (self.N-ix)*(elapsed/(ix+1))), end='')
+        print('\r{info}{}/{} ({:.2f}s - {:.2f}s remaining)'.format(ix+1, self.N, elapsed, (self.N-ix)*(elapsed/(ix+1))), end='')
 
 line = lambda N=66: print('='*N)
 def see(*X, N=66): list(map(lambda x: print('='*N+'\n{}'.format(x)), X))+[print('='*N)]
