@@ -1,9 +1,9 @@
-'v0.15.1'
-'''Todo
-- [ ] Make Colab compatible
-- [ ] have a better keyword for transient log (`templog`)
+'v0.15.2'
+'''Todo - v0.15.3
+- [x] Make Colab compatible
+- [ ] have a better keyword for transient log (`temp`)
 - [ ] accumulate values
-- [ ] convert to numpy if torch value is sent
+- [x] convert to numpy if torch value is sent
 - [ ] use regexs for plotting metrics
 - [ ] add .plot_epochs()
 '''
@@ -68,7 +68,7 @@ class Report:
         plt.grid(True)
         plt.xlabel('Epochs'); plt.ylabel('Metrics')
         plt.legend()
-        plt.show()        
+        plt.show()
 
     def report_avgs(self, epoch):
         avgs = {}
